<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\About;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;

class AboutController extends Controller
{
    // Display the Edit Form
    public function edit()
    {
        $abouts = About::first();
        return view('Admin.About.edit', compact('abouts'));
    }

    // Handle the Update Logic
    public function update(Request $request)
    {
        $abouts = About::first();
        $request->validate([
            'title' => 'required|string|max:255',
            'status' => 'required|boolean',
            'banner' => 'sometimes|file|image|max:2048',
            'signature' => 'sometimes|file|image|max:2048',
            'short_description' => 'nullable|string',
            'content' => 'nullable|string',
            'link' => 'nullable|string|max:255',
            'experience' => 'nullable|integer',
            'cumulative_experience' => 'nullable|integer',
            'trained' => 'nullable|integer',
            'businesses_catered' => 'nullable|integer',
            'meta_tag' => 'nullable|string|max:255',
            'meta_title' => 'nullable|string|max:255',
            'meta_description' => 'nullable|string',
        ]);

        $abouts->title = $request->input('title');
        $abouts->status = $request->input('status');
        $abouts->short_description = $request->input('short_description');
        $abouts->content = $request->input('content');
        $abouts->link = $request->input('link');
        $abouts->experience = $request->input('experience');
        $abouts->cumulative_experience = $request->input('cumulative_experience');
        $abouts->trained = $request->input('trained');
        $abouts->businesses_catered = $request->input('businesses_catered');
        $abouts->meta_tag = $request->input('meta_tag');
        $abouts->meta_title = $request->input('meta_title');
        $abouts->meta_description = $request->input('meta_description');

        // Handle banner upload
        if ($request->hasFile('banner')) {
            $bannerDestination = 'assets/img/about/' . $abouts->banner;
            if (File::exists($bannerDestination)) {
                File::delete($bannerDestination);
            }
            $bannerFile = $request->file('banner');
            $bannerExtension = $bannerFile->getClientOriginalExtension();
            $bannerFilename = time() . '.' . $bannerExtension;
            $bannerFile->move('assets/img/about', $bannerFilename);
            $abouts->banner = $bannerFilename;
        }

        // Handle signature upload
        if ($request->hasFile('signature')) {
            $signatureDestination = 'assets/img/about/' . $abouts->signature;
            if (File::exists($signatureDestination)) {
                File::delete($signatureDestination);
            }
            $signatureFile = $request->file('signature');
            $signatureExtension = $signatureFile->getClientOriginalExtension();
            $signatureFilename = time() . '.' . $signatureExtension;
            $signatureFile->move('assets/img/about', $signatureFilename);
            $abouts->signature = $signatureFilename;
        }

        $abouts->save();

        return redirect()->route('admin.about.edit')->withSuccess('success', 'About section updated successfully.');
    }
}
