<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Blog;
// use App\Models\BlogsCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\File;


class BlogsController extends Controller
{
    //users view
    public function index(Request $request)
    {

        $search = $request->query('search');
        $blogs = Blog::all();
        $blogs = Blog::when($search, function ($query) use ($search) {
            $query->where('name', 'like', '%' . $search . '%')
                ->orWhere('id', 'like', '%' . $search . '%')
                ->orWhere('title', 'like', '%' . $search . '%')
                ->orWhere('keyword', 'like', '%' . $search . '%');
        })
            ->orderByDesc('created_at')
            ->paginate(10);
        return view('Admin.Blogs.bloglist', compact('blogs'));
    }




    // Add Blog View
    public function add()
    {
        // $categories = BlogsCategory::all();
        return view('Admin.Blogs.add_blog');
    }

    //Creat Users
    public function store(Request $request)
    {
        //validation
        $request->validate([
            'name' => ['required', 'unique:blogs,name'],
            'slug' => ['required'],
            'title' => ['required'],
            'url' => ['required'],
            'short_description' => ['required'],
            'content' => ['required'],
            'image' => ['nullable', 'image', 'mimes:webp,jpeg,png,jpg,gif', 'max:2048'], // Allow webp and other formats
            'keyword' => ['required'],
            'image' => ['required'],
            'meta_tag' => ['required'],
            'meta_title' => ['required'],
            'meta_description' => ['required'],
            'status' => ['required'],
            // 'blog_category_id' => ['required'],

        ]);


        $blogs = new Blog;
        $blogs->name = $request->name;
        $blogs->slug = $request->slug;
        $blogs->title = $request->title;
        $blogs->url = $request->url;
        $blogs->short_description = $request->short_description;
        $blogs->content = $request->content;
        $blogs->keyword = $request->keyword;
        // $blogs->blog_category_id = $request->blog_category_id;
        $blogs->meta_tag = $request->meta_tag;
        $blogs->meta_title = $request->meta_title;
        $blogs->meta_description = $request->meta_description;
        $blogs->status = $request->status;




        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $filename = time() . '.' . $file->getClientOriginalExtension();

            // Ensure the directory exists
            if (!File::exists(public_path('assets/img/blog'))) {
                File::makeDirectory(public_path('assets/img/blog'), 0755, true);
            }

            // Move the new image to the directory
            $file->move(public_path('assets/img/blog'), $filename);

            // Update the image field in the model
            $blogs->image = $filename;
        }

        $blogs->save();
        return back()->withSuccess('Blog Created !!!!!');
    }

    public function checkSlug(Request $request)
    {
        $slug = Str::slug($request->name);
        return response()->json(['slug' => $slug]);
    }

    // Edit Blog View
    public function edit($id)
    {
        $blogs = Blog::findOrFail($id);
        // $categories = BlogsCategory::all();
        return view('Admin.Blogs.edit_blog', compact('blogs',));
    }

    //Upadte Users
    public function update(Request $request, $id)
    {
        //validation
        $request->validate([
            'name' => ['required', 'unique:blogs,name'],
            'slug' => ['required'],
            'image' => ['nullable', 'image', 'mimes:webp,jpeg,png,jpg,gif', 'max:2048'], // Allow webp and other formats
            'title' => ['required'],
            'url' => ['required'],
            'short_description' => ['required'],
            'content' => ['required'],
            'keyword' => ['required'],
            'meta_tag' => ['required'],
            'meta_title' => ['required'],
            'meta_description' => ['required'],
            'status' => ['required'],
            // 'blog_category_id' => ['required'],
        ]);

        $blogs = Blog::where('id', $id)->first();

        $blogs->name = $request->name;
        $blogs->slug = $request->slug;
        $blogs->title = $request->title;
        $blogs->url = $request->url;
        $blogs->short_description = $request->short_description;
        $blogs->content = $request->content;
        $blogs->keyword = $request->keyword;
        // $blogs->blog_category_id = $request->blog_category_id;
        $blogs->meta_tag = $request->meta_tag;
        $blogs->meta_title = $request->meta_title;
        $blogs->meta_description = $request->meta_description;
        $blogs->status = $request->status;



        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $filename = time() . '.' . $file->getClientOriginalExtension();

            // Ensure the directory exists
            if (!File::exists(public_path('assets/img/blog'))) {
                File::makeDirectory(public_path('assets/img/blog'), 0755, true);
            }

            // Delete the old image if it exists
            $destination = public_path('assets/img/blog/' . $blogs->image);
            if (File::exists($destination)) {
                File::delete($destination);
            }

            // Move the new image to the directory
            $file->move(public_path('assets/img/blog'), $filename);

            // Update the image field in the model
            $blogs->image = $filename;
        }

        $blogs->save();
        return redirect('/admin/blogs')->withSuccess('Blog Updated !!!!!');
    }


    // Delete Users
    public function destroy($id)
    {
        $blogs = Blog::where('id', $id)->first();
        $blogs->delete();
        return back()->withSuccess('Blog Deleted !!!!!');
    }


    public function show($slug)
    {
        // Find the post by slug
        $blogs = Blog::where('slug', $slug)->firstOrFail();


        // $blogs = Blog::with('comments')->where('slug', $slug)->firstOrFail();
        // dd($blogs);

        // Increment view count
        $blogs->increment('views');

        // Find the author of the post
        $author = $blogs->name;

        // Get the ID of the current post
        $currentPostId = $blogs->id;

        // Fetch posts by the same author excluding the current post
        $relatedPosts = Blog::where('name', $author)
            ->where('id', '!=', $currentPostId)
            ->get();

        // Return a view with the post data
        return view('Frontened/blog_show', compact('blogs', 'relatedPosts',));
    }
}
