<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Page;
use App\Models\Form;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\File;

class PagesController extends Controller
{
    // Pages list view
    public function index()
    {
        $pages = Page::get();
        return view('Admin.Pages.pagelist', compact('pages'));
    }

    // Add page view
    public function add()
    {

        return view('Admin.Pages.add_page');
    }

    // Store new page
    public function create(Request $request)
    {
        // Validation rules
        $request->validate([
            'name' => ['required'],
            'slug' => ['required', 'unique:pages,slug'],
            'title' => ['required'],
            'content' => ['nullable'],
            'meta_tag' => ['nullable'],
            'meta_title' => ['nullable'],
            'meta_description' => ['nullable'],
            'status' => ['required'],
        ]);

        $page = new Page;

        $page->name = $request->name;
        $page->slug = $request->slug;
        $page->title = $request->title;
        $page->content = $request->content;
        $page->meta_tag = $request->meta_tag;
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->status = $request->status;
        $page->save();
        return back()->withSuccess('Page Created !!!!!');
    }

    // Check and return slug via JSON
    public function checkSlug(Request $request)
    {
        $slug = Str::slug($request->name);
        return response()->json(['slug' => $slug]);
    }


    // Edit page view
    public function edit($id)
    {
        $page = Page::findOrFail($id);
        return view('Admin.Pages.edit_page', ['page' => $page]);
    }

    // Update page
    public function update(Request $request, $id)
    {
        // Validation rules
        $request->validate([
            'name' => ['required'],
            'slug' => ['required'],
            'title' => ['required'],
            'meta_tag' => ['nullable'],
            'meta_title' => ['nullable'],
            'meta_description' => ['nullable'],
            'status' => ['required'],
        ]);



        $page = Page::findOrFail($id);
        $page->name = $request->name;
        $page->slug = $request->slug;
        $page->title = $request->title;
        $page->content = $request->content;
        $page->meta_tag = $request->meta_tag;
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->status = $request->status;

        $page->save();
        return redirect('/admin/pages')->withSuccess('Page Updated !!!!!');
    }

    public function destroy($id)
    {
        $page = Page::findOrFail($id);
        $page->delete();
        return back()->withSuccess('Page Deleted !!!!!');
    }

    // public function show($slug)
    // {
    //     $pages = Page::where('slug', $slug)->firstOrFail();

    //     return view('Frontened/show_pages', compact('pages'));
    // }


}
