<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Review;
use App\Models\User;
use Illuminate\Http\Request;

class ReviewController extends Controller
{
    // Display all user reviews
    public function index(Request $request)
    {    

        $search = $request->query('search');
        $reviews = Review::with('userdata')->get(); // Fetch all user reviews
        $reviews = Review::when($search, function ($query) use ($search) {
            $query->where('id',  $search)
                  ->orWhere('user', 'like', '%' . $search . '%' )
                  ->orWhere('bio', 'like', '%' . $search . '%' )
                  ->orWhere('rating', 'like', '%' . $search . '%')
                  ->orWhere('visible', 'like', '%' . $search . '%');
                })
                ->orderByDesc('created_at')
                ->paginate(2);

        // dd($reviews);
        return view('Admin.Review.index', compact('reviews'));
    }


    // Show the form to add a new user review
    public function add()
    {   

        
        $users = User::all();
        return view('Admin.Review.add', compact('users'));
    }

    public function store(Request $request)
    {
        // Validate the request
     $request->validate([
            'user' => ['required'],
            'bio' => ['required'],
            'rating' => ['required'],
            'review' => ['required'],
            'visible' => ['required'],
        ]);

        $reviews = new Review;
        $reviews->user = $request->user;
        $reviews->bio = $request->bio;
        $reviews->rating = $request->rating;
        $reviews->review = $request->review;
        $reviews->visible = $request->visible;


        // Create a new record in the database
        $reviews->save();

        // Redirect or respond as needed
        return back()->withSuccess('success', 'review added successfully!');
    }



    // Show the form to edit a user review
    public function edit($id)
    {
        $reviews = Review::where('id', $id)->first();
        // Fetch the user review by ID
        $users = User::all();

        return view('Admin.Review.edit', ['reviews' => $reviews, 'users'=> $users]);
    }



    // Update an existing user review
    public function update(Request $request, $id)
    {
          // Validate the request
        $validatedData = $request->validate([
            'user' => ['required'],
            'bio' => ['required'],
            'rating' => ['required'],
            'review' => ['required'],
            'visible' => ['required'],
        ]);



        // Find the user review by ID
        $reviews = Review::findOrFail($id);

        $reviews->user = $request->user;
        $reviews->bio = $request->bio;
        $reviews->rating = $request->rating;
        $reviews->review = $request->review;
        $reviews->visible = $request->visible;

        // Update recored record in the database
        $reviews->save();

        // Redirect or respond as needed
        return redirect()->route('admin.reviews.index')->with('success', 'User review updated successfully!');
    }


    // Delete a review
    public function destroy($id)
    {
        $reviews = Review::where('id', $id)->first();
        $reviews->delete();

        return back()->with('success', 'Review deleted successfully!');
    }

}
