<?php

namespace App\Http\Controllers\admin;

use App\Models\User;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class UsersController extends Controller
{
    //users view
    public function index(Request $request)
    {

        $search = $request->query('search');
        $users = User::when($search, function ($query) use ($search) {
            $query->where('name', 'like', '%' . $search . '%' )
                  ->orWhere('id',  $search )
                  ->orWhere('last_name', 'like', '%' . $search . '%')
                  ->orWhere('email', 'like', '%' . $search . '%')
                  ->orWhere('address', 'like', '%' . $search . '%');

        })
        ->orderByDesc('created_at')
        ->paginate(10);
        return view('Admin.Users.userlist', compact('users'));
    }




    //add users view
    public function add()
    {

        return view('Admin.Users.add_user');
    }

    //Creat Users
    public function create(Request $request)
    {
        // Validate the form data
        $request->validate([
            'name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'contact_number' => 'nullable|string|max:20',
            'address' => 'nullable|string|max:255',
            'password' => 'required|string|min:8',
            'roll' => 'nullable|string|max:255',

            'gender' => 'nullable|string|in:male,female,other',
            'dob' => 'nullable|date',

            'billing_address' => 'nullable|string|max:255',
            'billing_city' => 'nullable|string|max:255',
            'billing_country' => 'nullable|string|max:255',
            'billing_zip_code' => 'nullable|string|max:20',
            'shipping_same_as_billing' => 'nullable|boolean',

            'shipping_address' => 'nullable|string|max:255',
            'shipping_city' => 'nullable|string|max:255',
            'shipping_country' => 'nullable|string|max:255',
            'shipping_zip_code' => 'nullable|string|max:20',
            'shipping_phone' => 'nullable|string|max:20',
            'newsletters' => 'nullable|in:yes,no',
            'organization' => 'nullable|string|max:255',
            'mailer_campaign' => 'nullable|string|max:255',
            'mailer_campaign_identifier_name' => 'nullable|string|max:255',
            'mailer_campaign_timestamp' => 'nullable|date',
            'mailer_source' => 'nullable|string|max:255',
            // Add more validation rules as needed
        ]);

        // Create new user record
        $user = new User();
        $user->name = $request->input('name');
        $user->last_name = $request->input('last_name');
        $user->email = $request->input('email');
        $user->contact_number = $request->input('contact_number');
        $user->address = $request->input('address');
        $user->password = bcrypt($request->input('password'));

        // Assign optional fields if provided
        $user->roll = $request->input('roll');

        $user->gender = $request->input('gender');
        $user->dob = $request->input('dob');

        // Assign billing details
        $user->billing_address = $request->input('billing_address');
        $user->billing_city = $request->input('billing_city');
        $user->billing_country = $request->input('billing_country');
        $user->billing_zip_code = $request->input('billing_zip_code');

        $check = isset($request->shipping_same_as_billing)  ? 1 : 0 ;
        $user->shipping_same_as_billing = $check;

        // Assign shipping details
        $user->shipping_address = $request->input('shipping_address');
        $user->shipping_city = $request->input('shipping_city');
        $user->shipping_country = $request->input('shipping_country');
        $user->shipping_zip_code = $request->input('shipping_zip_code');
        $user->shipping_phone = $request->input('shipping_phone');

        $user->newsletters = $request->input('newsletters');
        $user->organization = $request->input('organization');
        $user->mailer_campaign = $request->input('mailer_campaign');
        $user->mailer_campaign_identifier_name = $request->input('mailer_campaign_identifier_name');
        $user->mailer_campaign_timestamp = $request->input('mailer_campaign_timestamp');
        $user->mailer_source = $request->input('mailer_source');


        // Save the user
        $user->save();

        // Redirect back with success message
        return redirect()->route('admin.users')->with('success', 'User added successfully!');
    }

    //Edit users view
    public function edit($id)
    {
        $users = User::where('id', $id)->first();

        return view('Admin.Users.edit_user', ['users' => $users]);
    }

    //Upadte Users
    public function update(Request $request, $id)
    {
        //validation

        $request->validate([
            // 'name' => 'required|string|max:255',
            // 'last_name' => 'required|string|max:255',
            // 'email' => 'required|email|unique:users,email',
            // 'contact_number' => 'nullable|string|max:20',
            // 'address' => 'nullable|string|max:255',
            // 'password' => 'required|string|min:8',
            // 'roll' => 'nullable|string|max:255',
            // 'site' => 'nullable|string|max:255',
            // 'gender' => 'nullable|string|in:male,female,other',
            // 'dob' => 'nullable|date',

            // 'billing_address' => 'nullable|string|max:255',
            // 'billing_city' => 'nullable|string|max:255',
            // 'billing_country' => 'nullable|string|max:255',
            // 'billing_zip_code' => 'nullable|string|max:20',
            // 'shipping_same_as_billing' => 'nullable|boolean',

            // 'shipping_address' => 'nullable|string|max:255',
            // 'shipping_city' => 'nullable|string|max:255',
            // 'shipping_country' => 'nullable|string|max:255',
            // 'shipping_zip_code' => 'nullable|string|max:20',
            // 'shipping_phone' => 'nullable|string|max:20',


            // 'newsletters' => 'nullable|in:yes,no',
            // 'organization' => 'nullable|string|max:255',
            // 'mailer_campaign' => 'nullable|string|max:255',
            // 'mailer_campaign_identifier_name' => 'nullable|string|max:255',
            // 'mailer_campaign_timestamp' => 'nullable|date',
            // 'mailer_source' => 'nullable|string|max:255',
            // Add more validation rules as needed


        ]);


        $users = User::where('id', $id)->first();

        $users->name = $request->input('name');
        $users->last_name = $request->input('last_name');
        $users->email = $request->input('email');
        $users->contact_number = $request->input('contact_number');
        $users->address = $request->input('address');
        $users->password = bcrypt($request->input('password'));

        // Assign optional fields if provided
        $users->roll = $request->input('roll');

        $users->gender = $request->input('gender');
        $users->dob = $request->input('dob');

        // Assign billing details
        $users->billing_address = $request->input('billing_address');
        $users->billing_city = $request->input('billing_city');
        $users->billing_country = $request->input('billing_country');
        $users->billing_zip_code = $request->input('billing_zip_code');

        $check = isset($request->shipping_same_as_billing)  ? 1 : 0 ;
        $users->shipping_same_as_billing =$check;

        // Assign shipping details
        $users->shipping_address = $request->input('shipping_address');
        $users->shipping_city = $request->input('shipping_city');
        $users->shipping_country = $request->input('shipping_country');
        $users->shipping_zip_code = $request->input('shipping_zip_code');
        $users->shipping_phone = $request->input('shipping_phone');

        $users->newsletters = $request->input('newsletters');
        $users->organization = $request->input('organization');
        $users->mailer_campaign = $request->input('mailer_campaign');
        $users->mailer_campaign_identifier_name = $request->input('mailer_campaign_identifier_name');
        $users->mailer_campaign_timestamp = $request->input('mailer_campaign_timestamp');
        $users->mailer_source = $request->input('mailer_source');


        $users->save();
        return redirect()->route('admin.users')->with('success', 'User Updated !!!!!');

    }


    // Delete Users
    public function destroy($id)
    {
        $users = User::where('id', $id)->first();
        $users->delete();
        return back()->withSuccess('User Deleted !!!!!');

    }


}