@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Edit Blog</h1>
                <a href="{{ route('admin.blogs') }}" class="btn btn-sm btn-primary mb-0">Back</a>
            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <form action="{{ url('/admin/blogs-update', $blogs->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                <section class="content">
                    <!-- Default box -->
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <div class="row">

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="name">Name</label>
                                                    <input type="text" name="name" id="name"class="form-control"
                                                        placeholder="name" value="{{ old('name', $blogs->name) }}">
                                                    <span class="text-danger">
                                                        @error('name')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="slug">Slug</label>
                                                    <input type="text" name="slug" id="slug"class="form-control"
                                                        placeholder="slug" value="{{ old('slug',  $blogs->slug) }}" readonly>
                                                    <span class="text-danger">
                                                        @error('slug')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="title">Title</label>
                                                    <input type="text" name="title" id="title"class="form-control"
                                                        placeholder="title" value="{{ old('title', $blogs->title) }}">
                                                    <span class="text-danger">
                                                        @error('title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            {{-- <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="blog_category_id">Blog Category</label>
                                                    <select class="form-select" name="blog_category_id" id="blog_category_id" aria-label="Select Blog Category">
                                                        <option value="">Select Category</option>
                                                        @foreach($categories as $category)
                                                            <option value="{{ $category->id }}" {{ old('blog_category_id', $blogs->blog_category_id) == $category->id ? 'selected' : '' }}>
                                                                {{ $category->category }}
                                                            </option>
                                                        @endforeach
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('blog_category_id')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div> --}}

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="url">URL</label>
                                                    <input type="text" name="url"
                                                        id="url"class="form-control" placeholder="url"
                                                        value="{{ old('url',  $blogs->url) }}">
                                                    <span class="text-danger">
                                                        @error('url')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="short_description">Short Description</label>
                                                    <textarea name="short_description" id="short_description" class="form-control tinymce-editor">{{ old('short_description',$blogs->short_description) }}</textarea>
                                                    @error('short_description')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="content">Blog Content</label>
                                                    <textarea name="content" id="content" class="form-control tinymce-editor">{{ old('content', $blogs->content) }}</textarea>
                                                    @error('content')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="keyword">Post By</label>
                                                    <input type="text" name="keyword"
                                                        id="keyword"class="form-control" placeholder="User Name"
                                                        value="{{ old('keyword', $blogs->keyword) }}">
                                                    <span class="text-danger">
                                                        @error('keyword')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label class="form-label" for="customFile">Image</label>
                                                    <input type="file" name="image" class="form-control" id="image" />
                                                    @if ($blogs->image)
                                                        <p>Current Image: {{ $blogs->image }}</p>
                                                        <img src="{{ asset('assets/img/blog/' .$blogs->image) }}" width="100px" alt="">
                                                        <input type="hidden" name="old_image" value="{{ $blogs->image }}">
                                                    @else
                                                        <p>No current image</p>
                                                    @endif
                                                    <span class="text-danger">
                                                        @error('image')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_title">Meta Title </label>
                                                    <input type="text" name="meta_title"
                                                        id="meta_title"class="form-control" placeholder="meta title"
                                                        value="{{ old('meta_title',  $blogs->meta_title) }}">
                                                    <span class="text-danger">
                                                        @error('meta_title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_tag">Meta Keyword</label>
                                                    <input type="text" name="meta_tag" id="meta_tag"class="form-control"
                                                        placeholder="meta tag" value="{{ old('meta_tag', $blogs->meta_tag) }}">
                                                    <span class="text-danger">
                                                        @error('meta_tag')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="meta_description">Meta Description</label>
                                                    <textarea name="meta_description"
                                                        id="meta_description"class="form-control"
                                                        placeholder="meta description">{{ old('meta_description',  $blogs->meta_description) }}
                                                    </textarea>
                                                    <span class="text-danger">
                                                        @error('meta_description')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="status">Status</label>
                                                    <select class="form-select" name="status" id="status"
                                                        aria-label="Default select example">
                                                        <option value="">Select Status</option>
                                                        <option
                                                            value="1"{{ $blogs->status == 1 ? 'selected' : '' }}>
                                                            Active</option>
                                                        <option
                                                            value="0"{{ $blogs->status == 0 ? 'selected' : '' }}>
                                                            Dactive</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('status')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="pb-5 pt-3 text-center">
                        &nbsp;&nbsp;&nbsp;
                        <button class="btn btn-primary" type="submit">Update</button>
                        <a href="{{ route('admin.blogs') }}" class="btn btn-outline-dark ml-3">Cancel</a>
                    </div>
                </section>
            </form>
        </div>
    </div>




    <script src="{{ asset('assets/js/jquery.min.js') }}"></script>
    <script>
        $(document).ready(function() {
            $('#name').on('input', function() {
                var name = $(this).val();
                $.ajax({
                    url: "{{ route('admin.blogs.check_slug') }}",
                    method: 'POST',
                    data: {
                        _token: "{{ csrf_token() }}",
                        name: name
                    },
                    success: function(response) {
                        $('#slug').val(response.slug);
                    },
                    error: function(xhr) {
                        console.error(xhr);
                    }
                });
            });
        });
    </script>
@endsection

@section('titel')
Products/Edit
@endsection
