@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Faq List</h1>
                <a href="{{ route('admin.faqs.add') }}" class="btn btn-sm btn-primary mb-0">Add Faq</a>
            </div>
        </div>

        <!-- Card START -->
        <div class="card bg-transparent border">

            <!-- Card header START -->
            <div class="card-header bg-light border-bottom">
                <!-- Search and select START -->
                <div class="row g-3 align-items-center justify-content-between">
                    <!-- Search bar -->
                    <div class="col-md-3">
                        <form action="{{ route('admin.faqs') }}" method="GET" class="rounded position-relative">
                            <input name="search" class="form-control bg-body" type="search" placeholder="Search" aria-label="Search" value="{{ request()->get('search') }}">
                            <button class="bg-transparent p-2 position-absolute top-50 end-0 translate-middle-y border-0 text-primary-hover text-reset" type="submit">
                                <i class="fas fa-search fs-6"></i>
                            </button>
                        </form>
                    </div>

                    <!-- Select option -->
                    <div class="col-md-3">
                        <!-- Sort by filter -->
                        <form>
                            <select class="form-select js-choice border-0 z-index-9" aria-label=".form-select-sm">
                                <option value="">Sort by</option>
                                <option>Newest</option>
                                <option>Oldest</option>
                                <option>Accepted</option>
                                <option>Rejected</option>
                            </select>
                        </form>
                    </div>
                </div>
                <!-- Search and select END -->
            </div>
            <!-- Card header END -->

            <!-- Card body START -->
            <div class="card-body">
                <!-- Events table START -->
                <div class="table-responsive border-0 rounded-3">
                    <!-- Table START -->
                    <table class="table table-dark-gray align-middle p-4 mb-0 table-hover">
                        <!-- Table head -->
                        <thead>
                            <tr>
                                <th scope="col" class="border-0 rounded-start">Sr.No</th>
                                <th scope="col" class="border-0">Faq Question</th>
                                <th scope="col" class="border-0 text-center">Status</th>
                                <th scope="col" class="border-0">Create At</th>
                                <th scope="col" class="border-0">Update At</th>
                                <th scope="col" class="border-0 text-center rounded-end">Action</th>
                            </tr>
                        </thead>

                        <!-- Table body START -->
                        <tbody>
                            @foreach ($faqs as $data)
                                <!-- Table row -->
                                <tr>
                                    <td>{{ $data->id }}</td>

                                    <!-- Table data -->
                                    <td>
                                        <div class="d-flex align-items-center mb-3">
                                            <div class="ms-2">
                                                <h6 class="mb-0 fw-light">{{ $data->faq_question }}</h6>
                                            </div>
                                        </div>
                                    </td>

                                    <td class="text-sm text-center">
                                        @if ($data->Status == '1')
                                            <span class="badge text-bg-primary">Active</span>
                                        @else
                                            <span class="badge text-bg-danger">Inactive</span>
                                        @endif
                                    </td>

                                    <td>{{ $data->created_at->format('d/M/Y') }}</td>
                                    <td>{{ $data->updated_at->format('d/M/Y') }}</td>

                                    <!-- Table data -->
                                    <td class="text-center">
                                        <a href="{{ route('admin.faqs.edit', $data->id) }}"
                                            class="btn btn-sm btn-success-soft me-1 mb-1 mb-md-0"><i
                                                class="bi bi-pencil-square"></i> Edit</a>

                                        <a href="javascript:void(0);" class="btn btn-sm btn-danger-soft mb-0"
                                            onclick="deleteConfirmation('{{ route('admin.faqs.delete', $data->id) }}')">
                                            <i class="bi bi-trash"></i> Delete
                                        </a>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                        <!-- Table body END -->
                    </table>
                    <!-- Table END -->
                </div>
                <!-- Events table END -->
            </div>
            <!-- Card body END -->

            <!-- Card footer START -->
            <div class="card-footer bg-transparent pt-0">
                <!-- Pagination START -->
                <div class="d-sm-flex justify-content-sm-between align-items-sm-center">
                
                     {{$faqs->links()}}
                <!-- Pagination END -->
            </div>
            <!-- Card footer END -->
        </div>
        <!-- Card END -->
    </div>

    <!--- Modal -->
@endsection

@section('titel')
    Admin/Events
@endsection
