@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Add Page</h1>
                <a href="{{ route('admin.pages') }}" class="btn btn-sm btn-primary mb-0">Back</a>
            </div>
        </div>

        <!-- Card START -->
        <div class="card bg-transparent border">

            <form action="{{ route('admin.pages.create') }}" method="POST" enctype="multipart/form-data">
                @csrf
                <section class="content">
                    <!-- Default box -->
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <div class="row">

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="name">Page Name</label>
                                                    <input type="text" name="name" id="name" class="form-control"
                                                        placeholder="Name" value="{{ old('name') }}">
                                                    <span class="text-danger">
                                                        @error('name')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <input type="hidden" name="slug" id="slug" class="form-control"
                                                readonly placeholder="Slug" value="{{ old('slug') }}">

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="status">Status</label>
                                                    <select class="form-select" name="status" id="status"
                                                        aria-label="Default select example">
                                                        <option value="">Select Status</option>
                                                        <option value="1">Active</option>
                                                        <option value="0">Inactive</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('status')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="title">Title</label>
                                                    <input type="text" name="title" id="title" class="form-control"
                                                        placeholder="Title" value="{{ old('title') }}">
                                                    <span class="text-danger">
                                                        @error('title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="content">Page Content</label>
                                                    <textarea name="content" id="content" class="form-control tinymce-editor">{{ old('content') }}</textarea>
                                                    @error('content')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_tag">Meta Tag</label>
                                                    <input type="text" name="meta_tag" id="meta_tag"
                                                        class="form-control" placeholder="Meta Tag"
                                                        value="{{ old('meta_tag') }}">
                                                    <span class="text-danger">
                                                        @error('meta_tag')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_title">Meta Title </label>
                                                    <input type="text" name="meta_title" id="meta_title"
                                                        class="form-control" placeholder="Meta Title"
                                                        value="{{ old('meta_title') }}">
                                                    <span class="text-danger">
                                                        @error('meta_title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="meta_description">Meta Description</label>
                                                    <textarea name="meta_description" id="meta_description" class="form-control" placeholder="Meta Description">{{ old('meta_description') }}</textarea>
                                                    <span class="text-danger">
                                                        @error('meta_description')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="pb-5 pt-3 text-center">
                        <button class="btn btn-primary" type="submit">Add</button>
                        <a href="{{ route('admin.pages') }}" class="btn btn-outline-dark ml-3">Cancel</a>
                    </div>
                </section>
            </form>
        </div>
        <!-- /.card -->
    </div>
    <!-- Card END -->
@endsection

@section('script')
    <script>
        $(document).ready(function() {
            $('#name').on('input', function() {
                var name = $(this).val();
                $.ajax({
                    url: "{{ route('admin.pages.check_slug') }}",
                    method: 'POST',
                    data: {
                        _token: "{{ csrf_token() }}",
                        name: name
                    },
                    success: function(response) {
                        $('#slug').val(response.slug);
                    },
                    error: function(xhr) {
                        console.error(xhr);
                    }
                });
            });
        });
    </script>
@endsection

@section('title')
    Page/Add
@endsection
