@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Edit Team Member</h1>
                <a href="{{ route('admin.team') }}" class="btn btn-sm btn-primary mb-0">Back</a>
            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <form action="{{ route('admin.team.update', $teams->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                <section class="content">
                    <!-- Default box -->
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="name">Name</label>
                                                    <input type="text" name="name" id="name"class="form-control"
                                                        placeholder="name" value="{{ old('name', $teams->name) }}">
                                                    <span class="text-danger">
                                                        @error('name')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="designation">Designation</label>
                                                    <input type="text" name="designation"
                                                        id="designation"class="form-control" placeholder="designation"
                                                        value="{{ old('designation', $teams->designation) }}">
                                                    <span class="text-danger">
                                                        @error('designation')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="bio">bio</label>
                                                    <textarea name="bio" class="form-control tinymce-editor">{{ old('bio', $teams->bio) }}</textarea>
                                                    @error('bio')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>



                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="url">Linkedin URL</label>
                                                    <input type="text" name="url" id="url"class="form-control"
                                                        placeholder="url" value="{{ old('url', $teams->url) }}">
                                                    <span class="text-danger">
                                                        @error('url')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label class="form-label" for="customFile">Image</label>
                                                    <input type="file" name="image" class="form-control"
                                                        id="image" />
                                                    @if ($teams->image)
                                                        <p>Current Image: {{ $teams->image }}</p>
                                                        <img src="{{ asset('assets/img/team/' . $teams->image) }}"
                                                            width="100px" alt="">
                                                        <input type="hidden" name="old_image" value="{{ $teams->image }}">
                                                    @else
                                                        <p>No current image</p>
                                                    @endif
                                                    <span class="text-danger">
                                                        @error('image')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <hr class="mt-4">

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_tag">Meta Tag</label>
                                                    <input type="text" name="meta_tag" id="meta_tag"class="form-control"
                                                        placeholder="meta tag"
                                                        value="{{ old('meta_tag', $teams->meta_tag) }}">
                                                    <span class="text-danger">
                                                        @error('meta_tag')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_title">Meta Title </label>
                                                    <input type="text" name="meta_title"
                                                        id="meta_title"class="form-control" placeholder="meta title"
                                                        value="{{ old('meta_title', $teams->meta_title) }}">
                                                    <span class="text-danger">
                                                        @error('meta_title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="meta_description">Meta Description</label>
                                                    <textarea name="meta_description" id="meta_description"class="form-control" placeholder="meta description">{{ old('meta_description', $teams->meta_description) }}
                                                    </textarea>
                                                    <span class="text-danger">
                                                        @error('meta_description')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="status">Status</label>
                                                    <select class="form-select" name="status" id="status"
                                                        aria-label="Default select example">
                                                        <option value="">Select Status</option>
                                                        <option value="1"{{ $teams->status == 1 ? 'selected' : '' }}>
                                                            Active</option>
                                                        <option value="0"{{ $teams->status == 0 ? 'selected' : '' }}>
                                                            Dactive</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('status')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="pb-5 pt-3 text-center">
                        &nbsp;&nbsp;&nbsp;
                        <button class="btn btn-primary" type="submit">Update</button>
                        <a href="{{ route('admin.team') }}" class="btn btn-outline-dark ml-3">Cancel</a>
                    </div>
        </div>
        <!-- /.card -->
        </section>
        </form>
    </div>
    <!-- Card END -->
    </div>
@endsection

@section('titel')
    Team Member/Edit
@endsection
