@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Edit Testimonial</h1>
                <a href="{{ route('admin.testimonials') }}" class="btn btn-sm btn-primary mb-0">Back</a>
            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <form action="{{ route('admin.testimonial.update', $testimonials->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                <section class="content">
                    <!-- Default box -->
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <div class="row">


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="name">Name</label>
                                                    <input type="text" name="name" id="name"class="form-control"
                                                        placeholder="name" value="{{ old('name', $testimonials->name) }}">
                                                    <span class="text-danger">
                                                        @error('name')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="title">Title</label>
                                                    <input type="text" name="title" id="title"class="form-control"
                                                        placeholder="title" value="{{ old('title',$testimonials->title ) }}">
                                                    <span class="text-danger">
                                                        @error('title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="url">URL</label>
                                                    <input type="text" name="url" id="url"class="form-control"
                                                        placeholder="url" value="{{ old('url', $testimonials->url) }}">
                                                    <span class="text-danger">
                                                        @error('url')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="role">Role</label>
                                                    <input type="text" name="role"
                                                        id="role"class="form-control" placeholder="role"
                                                        value="{{ old('role',$testimonials->role) }}">
                                                    <span class="text-danger">
                                                        @error('role')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="t_content">Content</label>
                                                    <textarea name="t_content" id="t_content" class="form-control tinymce-editor">{{ old('t_content', $testimonials->t_content) }}</textarea>
                                                    @error('t_content')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>

                                           
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="rating">Rating</label>
                                                    <select class="form-select" name="rating" id="rating"
                                                        aria-label="Default select example">
                                                        <option value="">Select Rating</option>
                                                        <option value="1"{{ $testimonials->rating == 1 ? 'selected' : '' }}>1 Star</option>
                                                        <option value="2"{{ $testimonials->rating == 2 ? 'selected' : '' }}>2 Star</option>
                                                        <option value="3"{{ $testimonials->rating == 3 ? 'selected' : '' }}>3 Star</option>
                                                        <option value="4"{{ $testimonials->rating == 4 ? 'selected' : '' }}>4 Star</option>
                                                        <option value="5"{{ $testimonials->rating == 5 ? 'selected' : '' }}>5 Star</option>
                                                    </select> 
                                                    <span class="text-danger">
                                                        @error('rating')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="type">Type</label>
                                                    <select class="form-select" name="type" id="type"
                                                        aria-label="Default select example">
                                                        <option value="">Select Type</option>
                                                        <option
                                                        value="1"{{ $testimonials->type == 1 ? 'selected' : '' }}>
                                                        Text</option>
                                                    <option
                                                        value="2"{{ $testimonials->type == 2 ? 'selected' : '' }}>
                                                        Video</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('type')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="video">Video</label>
                                                    <input type="text" name="video"
                                                        id="video"class="form-control" placeholder="video"
                                                        value="{{ old('video',$testimonials->video) }}" disabled>
                                                    <span class="text-danger">
                                                        @error('video')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>



                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label class="form-label" for="customFile">Image</label>
                                                    <input type="file" name="image" class="form-control" id="image" />
                                                    @if ($testimonials->image)
                                                        <p>Current Image: {{ $testimonials->image }}</p>
                                                        <img src="assets/img/testimonial/{{ $testimonials->image }}" width="100px" alt="">
                                                        <input type="hidden" name="old_image" value="{{ $testimonials->image }}">
                                                    @else
                                                        <p>No current image</p>
                                                    @endif
                                                    <span class="text-danger">
                                                        @error('image')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_tag">Meta Tag</label>
                                                    <input type="text" name="meta_tag" id="meta_tag"class="form-control"
                                                        placeholder="meta tag" value="{{ old('meta_tag', $testimonials->meta_tag) }}">
                                                    <span class="text-danger">
                                                        @error('meta_tag')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_title">Meta Title </label>
                                                    <input type="text" name="meta_title"
                                                        id="meta_title"class="form-control" placeholder="meta title"
                                                        value="{{ old('meta_title', $testimonials->meta_title) }}">
                                                    <span class="text-danger">
                                                        @error('meta_title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="meta_description">Meta Description</label>
                                                    <textarea name="meta_description"
                                                        id="meta_description"class="form-control"
                                                        placeholder="meta description">{{ old('meta_description', $testimonials->meta_description) }}</textarea>
                                                        <span class="text-danger">
                                                            @error('meta_description')
                                                                {{ $message }}
                                                            @enderror
                                                        </span>
                                                    </div>
                                                </div>
                                                       
                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="status">Status</label>
                                                    <select class="form-select" name="status" id="status"
                                                        aria-label="Default select example">
                                                        
                                                        <option
                                                            value="1"{{ $testimonials->status == 1 ? 'selected' : '' }}>
                                                            Active</option>
                                                        <option
                                                            value="0"{{ $testimonials->status == 0 ? 'selected' : '' }}>
                                                            Dactive</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('status')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="pb-5 pt-3 text-center">
                        &nbsp;&nbsp;&nbsp;
                        <button class="btn btn-primary" type="submit">Update</button>
                        <a href="{{ route('admin.testimonials') }}" class="btn btn-outline-dark ml-3">Cancel</a>
                    </div>
        </div>
        <!-- /.card -->
        </section>
        </form>
    </div>
    <!-- Card END -->
    </div>
    <script src="assets/js/jquery.min.js"></script>
    <script>
        $(document).ready(function() {
            // Initial check on page load
            if ($('#type').val() == '2') {
                $('#video').prop('disabled', false);
            } else {
                $('#video').prop('disabled', true);
            }

            // Change event listener for type dropdown
            $('#type').change(function() {
                if ($(this).val() == '2') {
                    $('#video').prop('disabled', false);
                } else {
                    $('#video').prop('disabled', true);
                }
            });
        });
    </script>

@endsection

@section('titel')
   Testimonial/Edit
@endsection







                        





