@extends('Admin.layout.layout')
@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">User List</h1>
                <a href="{{ route('admin.user.add') }}" class="btn btn-sm btn-primary mb-0">Add User</a>
            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <!-- Card header START -->
            <div class="card-header bg-light border-bottom">
                <!-- Search and select START -->
                <div class="row g-3 align-items-center justify-content-between">
                    <!-- Search bar -->
                    <div class="col-md-3">
                        <form action="{{ route('admin.users') }}" method="GET" class="rounded position-relative">
                            <input name="search" class="form-control bg-body" type="search" placeholder="Search"
                                aria-label="Search" value="{{ request()->get('search') }}">
                            <button
                                class="bg-transparent p-2 position-absolute top-50 end-0 translate-middle-y border-0 text-primary-hover text-reset"
                                type="submit">
                                <i class="fas fa-search fs-6"></i>
                            </button>
                        </form>
                    </div>
                    <!-- Search and select END -->
                </div>
                <!-- Card header END -->

                <!-- Card body START -->
                <div class="card-body">
                    <!-- Course table START -->
                    <div class="table-responsive border-0 rounded-3">
                        <!-- Table START -->
                        <table class="table table-dark-gray align-middle p-4 mb-0 table-hover">
                            <!-- Table head -->
                            <thead>
                                <tr>
                                    <th scope="col" class="border-0 rounded-start">Full Name</th>
                                    <th scope="col" class="border-0">Email</th>
                                    <th scope="col" class="border-0">Creat Date</th>
                                    <th scope="col" class="border-0">Update Date</th>
                                    <th scope="col" class="border-0 text-center rounded-end">Action</th>
                                </tr>
                            </thead>

                            <!-- Table body START -->
                            <tbody>
                                @foreach ($users as $user)
                                    <!-- Table row -->
                                    <tr>


                                        <!-- Table data -->
                                        <td>
                                            <div class="d-flex align-items-center mb-3">
                                                <!-- Avatar -->
                                                <div class="avatar avatar-xs flex-shrink-0">
                                                    <img class="avatar-img rounded-circle" src="{{ asset('assets/images/avatar/09.jpg') }}"
                                                        alt="avatar">
                                                </div>
                                                <!-- Info -->
                                                <div class="ms-2">
                                                    <h6 class="mb-0 fw-light">{{ $user->name }} {{ $user->last_name }}
                                                    </h6>
                                                </div>
                                            </div>
                                        </td>

                                        <!-- Table data -->
                                        <td>{{ $user->email }}</td>
                                        <td>{{ $user->created_at->format('d-m-y') }}</td>
                                        <td>{{ $user->updated_at->format('d-m-y') }}</td>

                                        <!-- Table data -->
                                        <td class="text-center">
                                            <a href="{{ route('admin.user.edit', $user->id) }}"
                                                class="btn btn-success-soft btn-round me-1 mb-1 mb-md-0"
                                                data-bs-toggle="tooltip" data-bs-placement="top" title=""
                                                data-bs-original-title="Edit">
                                                <i class="bi bi-pencil-square"></i>
                                            </a>

                                            <a href="javascript:void(0);"
                                                class="btn btn-danger-soft btn-round me-1 mb-1 mb-md-0"
                                                onclick="deleteConfirmation('{{ route('admin.user.delete', $user->id) }}')"
                                                data-bs-toggle="tooltip" data-bs-placement="top" title=""
                                                data-bs-original-title="Delete">
                                                <i class="bi bi-trash"></i>
                                            </a>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                            <!-- Table body END -->
                        </table>
                        <!-- Table END -->
                    </div>
                    <!-- Course table END -->
                </div>
                <!-- Card body END -->

                <!-- Card footer START -->
                <div class="card-footer bg-transparent pt-0">
                    <!-- Pagination START -->

                    {{ $users->links() }}

                    <!-- Pagination END -->
                </div>
                <!-- Card footer END -->
            </div>
            <!-- Card END -->
        </div>


        <!--- Modal -->
    @endsection

    @section('titel')
        Users
    @endsection
