@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Edit Article</h1>
                <a href="{{ route('admin.webinar') }}" class="btn btn-sm btn-primary mb-0">Back</a>
            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <form action="{{ route('admin.webinar.update', $webinars->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                <section class="content">
                    <!-- Default box -->
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <div class="row">



                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="name">Name</label>
                                                    <input type="text" name="name" id="name"class="form-control"
                                                        placeholder="name" value="{{ old('name', $webinars->name) }}">
                                                    <span class="text-danger">
                                                        @error('name')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="slug">Slug</label>
                                                    <input type="text" name="slug" id="slug"class="form-control"
                                                        placeholder="slug" value="{{ old('slug', $webinars->slug) }}"
                                                        readonly>
                                                    <span class="text-danger">
                                                        @error('slug')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="title">Title</label>
                                                    <input type="text" name="title" id="title"class="form-control"
                                                        placeholder="title" value="{{ old('title', $webinars->title) }}">
                                                    <span class="text-danger">
                                                        @error('title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label class="form-label" for="customFile">Image</label>
                                                    <input type="file" name="image" class="form-control"
                                                        id="image" />
                                                    @if ($webinars->image)
                                                        <p>Current Image: {{ $webinars->image }}</p>
                                                        <img src="assets/img/webinar/{{ $webinars->image }}" width="100px"
                                                            alt="">
                                                        <input type="hidden" name="old_image"
                                                            value="{{ $webinars->image }}">
                                                    @else
                                                        <p>No current image</p>
                                                    @endif
                                                    <span class="text-danger">
                                                        @error('image')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="short_description">Short Description</label>
                                                    <textarea name="short_description" id="short_description" class="form-control tinymce-editor">{{ old('short_description', $webinars->short_description) }}</textarea>
                                                    @error('short_description')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="content">Article Content</label>
                                                    <textarea name="content" id="content" class="form-control tinymce-editor">{{ old('content', $webinars->content) }}</textarea>
                                                    @error('content')
                                                        <span class="text-danger">{{ $message }}</span>
                                                    @enderror
                                                </div>
                                            </div>

                                            <hr class="mt-2 mb-4">

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="status">Status</label>
                                                    <select class="form-select" name="status" id="status"
                                                        aria-label="Default select example">
                                                        <option
                                                            value="1"{{ $webinars->status == 1 ? 'selected' : '' }}>
                                                            Active</option>
                                                        <option
                                                            value="0"{{ $webinars->status == 0 ? 'selected' : '' }}>
                                                            Dactive</option>
                                                    </select>
                                                    <span class="text-danger">
                                                        @error('status')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="popular">Is Popular</label>
                                                    <div style="display: flex; align-items: center;">
                                                        <div style="margin-right: 10px;">
                                                            <input type="radio" id="popular_yes" name="popular" value="yes" {{ $webinars->popular == 'yes' ? 'checked' : '' }}>
                                                            <label for="popular_yes">Yes</label>
                                                        </div>
                                                        <div>
                                                            <input type="radio" id="popular_no" name="popular" value="no" {{ $webinars->popular == 'no' ? 'checked' : '' }}>
                                                            <label for="popular_no">No</label>
                                                        </div>
                                                    </div>
                                                    <span class="text-danger">
                                                        @error('popular')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>


                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_title">Meta Title </label>
                                                    <input type="text" name="meta_title"
                                                        id="meta_title"class="form-control" placeholder="meta title"
                                                        value="{{ old('meta_title', $webinars->meta_title) }}">
                                                    <span class="text-danger">
                                                        @error('meta_title')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="mb-3">
                                                    <label for="meta_tag">Meta Keyword</label>
                                                    <input type="text" name="meta_tag"
                                                        id="meta_tag"class="form-control" placeholder="meta tag"
                                                        value="{{ old('meta_tag', $webinars->meta_tag) }}">
                                                    <span class="text-danger">
                                                        @error('meta_tag')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <label for="meta_description">Meta Description</label>
                                                    <textarea name="meta_description" id="meta_description"class="form-control" placeholder="meta description">{{ old('meta_description', $webinars->meta_description) }}
                                                    </textarea>
                                                    <span class="text-danger">
                                                        @error('meta_description')
                                                            {{ $message }}
                                                        @enderror
                                                    </span>
                                                </div>
                                            </div>

                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="pb-5 pt-3 text-center">
                        &nbsp;&nbsp;&nbsp;
                        <button class="btn btn-primary" type="submit">Update</button>
                        <a href="{{ route('admin.webinar') }}" class="btn btn-outline-dark ml-3">Cancel</a>
                    </div>
                </section>
            </form>
        </div>
    </div>

    <script src="{{ asset('assets/js/jquery.min.js') }}"></script>

    <script>
        $(document).ready(function() {
            $('#name').on('input', function() {
                var name = $(this).val();
                $.ajax({
                    url: "{{ route('admin.webinar.check_slug') }}",
                    method: 'POST',
                    data: {
                        _token: "{{ csrf_token() }}",
                        name: name
                    },
                    success: function(response) {
                        $('#slug').val(response.slug);
                    },
                    error: function(xhr) {
                        console.error(xhr);
                    }
                });
            });
        });
    </script>

@endsection

@section('titel')
    Article/Edit
@endsection
