@extends('Admin.layout.layout')

@section('admin_content')
    @if (Session::has('success'))
        <div class="alert alert-success alert-block">
            <strong>{{ Session::get('success') }}</strong>
        </div>
    @endif

    <div class="page-content-wrapper border">

        <!-- Title -->
        <div class="row mb-3">
            <div class="col-12 d-sm-flex justify-content-between align-items-center">
                <h1 class="h3 mb-2 mb-sm-0">Submitted Assignment</h1>

            </div>
        </div>


        <!-- Card START -->
        <div class="card bg-transparent border">

            <!-- Card header START -->
            <div class="card-header bg-light border-bottom">
                <!-- Search and select START -->
                <div class="row g-3 align-items-center justify-content-between">
                    <!-- Search bar -->
                    <div class="col-md-3">
                        <form action="{{ route('admin.assignment.show') }}" method="GET" class="rounded position-relative">
                            <input name="search" class="form-control bg-body" type="search" placeholder="Search"
                                aria-label="Search" value="{{ request()->get('search') }}">
                            <button
                                class="bg-transparent p-2 position-absolute top-50 end-0 translate-middle-y border-0 text-primary-hover text-reset"
                                type="submit">
                                <i class="fas fa-search fs-6"></i>
                            </button>
                        </form>
                    </div>

                    <!-- Select option -->
                    <div class="col-md-3">
                        <!-- Short by filter -->
                        <form method="GET" action="{{ route('admin.assignment.show') }}">

                            <select class="form-select js-choice border-0 z-index-9" name="sort"
                                aria-label=".form-select-sm" onchange="this.form.submit()">
                                <option value="">Sort by</option>
                                <option value="newest" {{ request('sort') == 'newest' ? 'selected' : '' }}>Newest</option>
                                <option value="oldest" {{ request('sort') == 'oldest' ? 'selected' : '' }}>Oldest</option>

                            </select>
                        </form>
                    </div>
                </div>
                <!-- Search and select END -->
            </div>
            <!-- Card header END -->

            <!-- Card body START -->
            <div class="card-body">
                <!-- Course table START -->
                <div class="table-responsive border-0 rounded-3">
                    <!-- Table START -->
                    <table class="table table-dark-gray align-middle p-4 mb-0 table-hover">
                        <!-- Table head -->
                        <thead>
                            <tr>
                                <th scope="col" class="border-0 rounded-start">Sr.No</th>
                                <th scope="col" class="border-0">Student</th>
                                <th scope="col" class="border-0">Assignment</th>
                                <th scope="col" class="border-0">Email</th>
                                <th scope="col" class="border-0 text-center rounded-end">Action</th>
                            </tr>
                        </thead>





                        <!-- Table body START -->
                        <tbody>
                            @foreach ($assignment as $data)
                                <!-- Table row -->
                                <tr>
                                    <td>{{ $loop->iteration }}</td>


                                    <!-- Table data -->
                                    <td>
                                        @if ($data->student && ($data->student->f_name || $data->student->l_name))
                                            {{ $data->student->f_name . ' ' . $data->student->l_name }}
                                        @else
                                            No student found
                                        @endif
                                    </td>

                                    <td>
                                        {{ $data->assignment->name }}
                                    </td>

                                    <td>

                                        @if ($data->student && $data->student->email)
                                            {{ $data->student->email }}
                                        @else
                                            No student found
                                        @endif

                                    </td>

                                    <!-- Table data -->
                                    <td class="text-center">
                                        <button type="button" class="btn btn-primary-soft btn-round me-1 mb-1 mb-md-0"
                                            data-bs-toggle="modal" data-bs-target="#assignmentModal{{ $data->id }}">
                                            <i class="bi bi-eye"></i>
                                        </button>

                                        <a href="javascript:void(0);"
                                            class="btn btn-danger-soft btn-round me-1 mb-1 mb-md-0"
                                            onclick="deleteConfirmation('{{ route('admin.assignment.destroy', $data->id) }}')"
                                            data-bs-toggle="tooltip" data-bs-placement="top" title=""
                                            data-bs-original-title="Delete">
                                            <i class="bi bi-trash"></i>
                                        </a>

                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                        <!-- Table body END -->
                    </table>
                    <!-- Table END -->
                </div>
                <!-- Course table END -->
            </div>
            <!-- Card body END -->

            <!-- Card footer START -->
            <div class="card-footer bg-transparent pt-0">
                <!-- Pagination START -->
                <div class="d-sm-flex justify-content-sm-between align-items-sm-center">

                    <!-- Pagination -->

                    {{ $assignment->links() }}

                    <!-- Pagination END -->
                </div>
                <!-- Card footer END -->
            </div>
            <!-- Card END -->
        </div>

        @foreach ($assignment as $data)
            <!-- Assignment Details Modal -->
            <div class="modal fade" id="assignmentModal{{ $data->id }}" tabindex="-1"
                aria-labelledby="assignmentModalLabel{{ $data->id }}" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="assignmentModalLabel{{ $data->id }}">
                                Assignment Details (ID: {{ $data->id }})</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                        </div>
                        <div class="modal-body">
                            <!-- Displaying assignment details -->
                            <p><strong>Name:</strong>

                                @if ($data->student && ($data->student->f_name || $data->student->l_name))
                                    {{ $data->student->f_name . ' ' . $data->student->l_name }}
                                @else
                                    No student found
                                @endif
                            </p>
                            <p><strong>Assignment:</strong> {{ $data->assignment->name }}</p>
                            <p><strong>Email:</strong>
                                @if ($data->student && $data->student->email)
                                    {{ $data->student->email }}
                                @else
                                    No student found
                                @endif
                            </p>
                            <p><strong>Answer:</strong> {{ $data->answer }}</p>

                            @if ($data->file)
                                <p><strong>File:</strong>
                                    <a href="{{ asset('frontened/assets/file/assignment/' . $data->file) }}"
                                        target="_blank">Download File
                                    </a>
                                </p>
                            @endif
                        </div>
                    </div>
                </div>
            </div>
        @endforeach
    @endsection

    @section('titel')
        Assignment
    @endsection
