<?php

use App\Http\Controllers\Admin\BlogsController;
use App\Http\Controllers\Admin\ContactRequestsController;
use App\Http\Controllers\Admin\TeamsController;
use App\Http\Controllers\Admin\PartnerController;
use App\Http\Controllers\Admin\SettingController;
use App\Http\Controllers\Admin\TestimonialsController;
use App\Http\Controllers\Admin\UsersController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;


Route::get('/admin', function () {
    return redirect('/admin/team');
})->middleware(['auth', 'verified'])->name('dashboard');


Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    // Contact request Management
    Route::get('/admin/contact-request', [ContactRequestsController::class, 'index'])->name('admin.contact.request');
    Route::get('/admin/contact-request-edit/{id}', [ContactRequestsController::class, 'edit'])->name('admin.contact.request.edit');
    Route::post('/admin/contact-request-update/{id}', [ContactRequestsController::class, 'update'])->name('admin.contact.request.update');
    Route::get('/admin/contact-request-delete/{id}', [ContactRequestsController::class, 'destroy'])->name('admin.contact.request.delete');

    // Team Management
    Route::get('/admin/team', [TeamsController::class, 'index'])->name('admin.team');
    Route::get('/admin/team-add', [TeamsController::class, 'add'])->name('admin.team.add');
    Route::post('/admin/team-create', [TeamsController::class, 'create'])->name('admin.team.create');
    Route::get('/admin/team-edit/{id}', [TeamsController::class, 'edit'])->name('admin.team.edit');
    Route::post('/admin/team-update/{id}', [TeamsController::class, 'update'])->name('admin.team.update');
    Route::get('/admin/team-delete/{id}', [TeamsController::class, 'destroy'])->name('admin.team.delete');

    // User management
    Route::get('/admin/users', [UsersController::class, 'index'])->name('admin.users');
    Route::get('/search', [UsersController::class, 'search'])->name('admin.users.search');
    Route::get('/user-add', [UsersController::class, 'add'])->name('admin.user.add');
    Route::post('/user-create', [UsersController::class, 'create'])->name('admin.user.create');
    Route::get('/user-edit/{id}', [UsersController::class, 'edit'])->name('admin.user.edit');
    Route::post('/user-update/{id}', [UsersController::class, 'update'])->name('admin.user.update');
    Route::get('/user-delete/{id}', [UsersController::class, 'destroy'])->name('admin.user.delete');


    // Blogs Management
    Route::get('/admin/blogs', [BlogsController::class, 'index'])->name('admin.blogs');
    Route::get('/admin/blogs-add', [BlogsController::class, 'add'])->name('admin.blogs.add');
    Route::post('/admin/blogs-store', [BlogsController::class, 'store'])->name('admin.blogs.store');
    Route::get('/admin/blogs-edit/{id}', [BlogsController::class, 'edit'])->name('admin.blogs.edit');
    Route::post('/admin/blogs-update/{id}', [BlogsController::class, 'update'])->name('admin.blogs.update');
    Route::get('/admin/blogs-destroy/{id}', [BlogsController::class, 'destroy'])->name('admin.blogs.destroy');
    Route::post('/admin/blogs/check-slug', [BlogsController::class, 'checkSlug'])->name('admin.blogs.check_slug');

    // Testionial Management
    Route::get('/admin/testimonials', [TestimonialsController::class, 'index'])->name('admin.testimonials');
    Route::get('/admin/testimonial-add', [TestimonialsController::class, 'add'])->name('admin.testimonial.add');
    Route::post('/admin/testimonial-store', [TestimonialsController::class, 'store'])->name('admin.testimonial.store');
    Route::get('/admin/testimonial-edit/{id}', [TestimonialsController::class, 'edit'])->name('admin.testimonial.edit');
    Route::post('/admin/testimonial-update/{id}', [TestimonialsController::class, 'update'])->name('admin.testimonial.update');
    Route::get('/admin/testimonial-destroy/{id}', [TestimonialsController::class, 'destroy'])->name('admin.testimonial.destroy');

    // Partners management
    Route::get('/admin/partners', [PartnerController::class, 'index'])->name('admin.partners');
    Route::get('/admin/partner-add', [PartnerController::class, 'add'])->name('admin.partner.add');
    Route::post('/admin/partner-create', [PartnerController::class, 'create'])->name('admin.partner.create');
    Route::get('/admin/partner-edit/{id}', [PartnerController::class, 'edit'])->name('admin.partner.edit');
    Route::post('/admin/partner-update/{id}', [PartnerController::class, 'update'])->name('admin.partner.update');
    Route::get('/admin/partner-delete/{id}', [PartnerController::class, 'destroy'])->name('admin.partner.delete');


    // Settings management
    Route::get('/settings', [SettingController::class, 'index'])->name('admin.settings');
    Route::post('admin/setting-update', [SettingController::class, 'update'])->name('admin.setting.update');
});


// Home Controller
Route::get('/', [HomeController::class, 'index'])->name('index');
Route::get('/home', [HomeController::class, 'index'])->name('index');
Route::get('/about-us', [HomeController::class, 'about_us'])->name('about-us');
Route::get('/solutions', [HomeController::class, 'solutions'])->name('solutions');
Route::get('/blogs', [HomeController::class, 'blogs'])->name('blogs');
Route::get('/blogs/{slug}', [BlogsController::class, 'show'])->name('posts.show');
Route::get('/cliente', [HomeController::class, 'cliente'])->name('cliente');
Route::get('/contact-us', [HomeController::class, 'contact_us'])->name('contact_us');

Route::post('/contact-request-create', [ContactRequestsController::class, 'create'])->name('contact.request.create');


require __DIR__ . '/auth.php';

// Route::get('/{slug}', [PagesController::class, 'show'])->name('pages.show');